### Additional functionalities

The command line tool ```opengate_user_info``` allo to print all default and possible parameters for Volumes, Sources, Physics and Actors elements. This is very verbose but allow to have a dynamic documentation of everything currently available in the installed gate version.

The "contrib" folder contains additional functions that are useful but do not belong to the core of GATE.

The functions are used in several tests.

A readme file can be found : https://github.com/OpenGATE/opengate/tree/master/opengate/contrib/readme.md

#### Dose rate computation

#### Linac : Elekta Synergy (warning: approximate model)

#### Phantom: IEC 6 spheres NEMA phantom

#### Voxelization of the IEC 6 spheres phantom

#### Phantom: cylinder phantom for PET NECR

#### SPECT GE NM 670 (warning: approximate model)

#### SPECT "ideal reconstruction"

#### PET Philips Vereos
